@@ -1,6 +1,6 @@
 /* context2.h -- manages the libSieve opaque context and callbacks.
  * Aaron Stone
- * $Id: context2.h 101 2006-11-26 02:48:15Z sodabrew $
+ * $Id: context2.h 125 2007-10-10 08:04:14Z sodabrew $
  */
 /* * * *
  * Copyright 2005 by Aaron Stone
@@ -29,6 +29,8 @@ struct callbacks2 {
     sieve2_callback_func addflag;
     sieve2_callback_func removeflag;
 
+    sieve2_callback_func err_header;
+    sieve2_callback_func err_address;
     sieve2_callback_func err_runtime;
     sieve2_callback_func err_parse;
     sieve2_callback_func debug_trace;
@@ -80,6 +82,7 @@ struct script2 {
     int error_count;
     int error_lineno;
     const char *script;
+    int length;
     commandlist_t *cmds;
 };
 
