@@ -1,6 +1,6 @@
 /* script2.c -- sieve script functions for version 2 api
  * Aaron Stone
- * $Id: script2.c 101 2006-11-26 02:48:15Z sodabrew $
+ * $Id: script2.c 125 2007-10-10 08:04:14Z sodabrew $
  */
 /* * * *
  * Copyright 2003, 2005 by Aaron Stone
@@ -155,6 +155,9 @@ int sieve2_callbacks(sieve2_context_t *context,
 
           CBCASE(SIEVE2_ERRCALL_RUNTIME,       err_runtime);
           CBCASE(SIEVE2_ERRCALL_PARSE,         err_parse);
+          CBCASE(SIEVE2_ERRCALL_HEADER,        err_header);
+          CBCASE(SIEVE2_ERRCALL_ADDRESS,       err_address);
+
           CBCASE(SIEVE2_DEBUG_TRACE,           debug_trace);
 
           CBCASE(SIEVE2_SCRIPT_GETSCRIPT,      getscript);
@@ -189,7 +192,7 @@ int sieve2_validate(sieve2_context_t *context, void *user_data)
     c->script.error_lineno = 1;        /* Reset line number */
 
     /* First callback already! Get the script! */
-    if (libsieve_do_getscript(c, "", "", &c->script.script) != SIEVE2_OK)
+    if (libsieve_do_getscript(c, "", "", &c->script.script, &c->script.length) != SIEVE2_OK)
         return SIEVE2_ERROR_GETSCRIPT;
 
     try {
@@ -229,7 +232,7 @@ int sieve2_execute(sieve2_context_t *context, void *user_data)
     c->script.error_lineno = 1;        /* Reset line number */
 
     /* First callback already! Get the script! */
-    if (libsieve_do_getscript(c, "", "", &c->script.script) != SIEVE2_OK)
+    if (libsieve_do_getscript(c, "", "", &c->script.script, &c->script.length) != SIEVE2_OK)
         return SIEVE2_ERROR_GETSCRIPT;
 
     try {
