@@ -1,6 +1,6 @@
 /* test.c -- test and example for sieve version 2 api
  * Aaron Stone
- * $Id: example.c 103 2006-11-27 20:12:25Z sodabrew $
+ * $Id: example.c 125 2007-10-10 08:04:14Z sodabrew $
  *
  * usage: "test message script"
  */
@@ -119,7 +119,7 @@ int my_vacation(sieve2_context_t *s, void *my)
 	int yn;
 
 	/* Ask for the message hash, the days parameters, etc. */
-	printf("Have I already responded to '%s' in the past %d days?\n",
+	fprintf(stderr, "Have I already responded to '%s' in the past %d days?\n",
 		sieve2_getvalue_string(s, "hash"),
 		sieve2_getvalue_int(s, "days") );
 
@@ -212,7 +212,33 @@ int my_errparse(sieve2_context_t *s, void *my)
 {
 	struct my_context *m = (struct my_context *)my;
 
-	printf( "Error is PARSE: " );
+	printf( "Error is SCRIPT PARSE: " );
+	printf( "  Line is %d\n",
+		sieve2_getvalue_int(s, "lineno"));
+	printf( "  Message is %s\n",
+		sieve2_getvalue_string(s, "message"));
+
+	m->error_parse = 1;
+	return SIEVE2_OK;
+}
+
+int my_erraddress(sieve2_context_t *s, void *my)
+{
+//	struct my_context *m = (struct my_context *)my;
+
+	printf( "Error is ADDRESS PARSE: " );
+	printf( "  Message is %s\n",
+		sieve2_getvalue_string(s, "message"));
+
+//	m->error_parse = 1;
+	return SIEVE2_OK;
+}
+
+int my_errheader(sieve2_context_t *s, void *my)
+{
+	struct my_context *m = (struct my_context *)my;
+
+	printf( "Error is HEADER PARSE: " );
 	printf( "  Line is %d\n",
 		sieve2_getvalue_int(s, "lineno"));
 	printf( "  Message is %s\n",
@@ -437,7 +463,8 @@ sieve2_callback_t my_callbacks[] = {
 { SIEVE2_DEBUG_TRACE,           my_debug         },
 { SIEVE2_ERRCALL_PARSE,         my_errparse      },
 { SIEVE2_ERRCALL_RUNTIME,       my_errexec       },
-{ SIEVE2_ERRCALL_PARSE,         my_errparse      },
+{ SIEVE2_ERRCALL_ADDRESS,       my_erraddress    },
+{ SIEVE2_ERRCALL_HEADER,        my_errheader     },
 { SIEVE2_ACTION_FILEINTO,       my_fileinto      },
 { SIEVE2_ACTION_DISCARD,        my_discard       },
 { SIEVE2_ACTION_REDIRECT,       my_redirect      },
