@@ -1,5 +1,5 @@
 /* util.h -- utility routines for useful things
- * $Id: util.h 108 2007-02-02 06:59:57Z sodabrew $
+ * $Id: util.h 116 2007-09-26 07:40:30Z sodabrew $
  */
 /* * * *
  * Copyright 2005 by Aaron Stone
@@ -13,8 +13,6 @@
 
 /* Needed for printf. */
 #include <stdio.h>
-/* Needed for vasprintf. */
-#include "vasprintf.h"
 #include "exception.h"
 
 /* Define several macros for GCC specific attributes.
